structure(list(method = "GET", url = "/list?logical-path=%2FtempZone%2Fhome%2Fprojectx%2Ftest.rds&stat=0&permissions=0&metadata=0&offset=0&limit=100", 
    status_code = 400L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:39 GMT", `Content-Length` = "107", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = raw(0)), class = "httr2_response")
